Chat.add_css() — alfred3_interact

Skip to main content
`Ctrl`+`K`

# Chat.add_css()

Chat.add_css(code: str, priority: int = 10)

  Adds CSS to the element.

  This is most useful when writing new elements. To simply add element-related CSS code to a page, usually the `CSS` element is a better choice.

  Parameters

    - code – Css code

    - priority – Can be used to influence the order in which code is added to the page. Sorting is ascending, i.e. the lowest numbers appear closest to the top of the page.

  See also

  - The `Style` element can be used to add generic CSS code to a page.

  - See `Element.css_class_element` and `Element.css_class_container` for information on element CSS classes and IDs.